==> proguard_3.9.orig.tar.gz: proguard3.9/src/proguard/classfile/util/WarningPrinter.java <==
/* $Id: WarningPrinter.java,v 1.1.2.2 2007/01/18 21:31:51 eric Exp $
 *
 * ProGuard -- shrinking, optimization, and obfuscation of Java class files.
 *
 * Copyright (c) 2002-2007 Eric Lafortune (eric@graphics.cornell.edu)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package proguard.classfile.util;

import proguard.classfile.visitor.*;
import proguard.classfile.attribute.*;
import proguard.classfile.attribute.annotation.*;
import proguard.classfile.*;

import java.io.PrintStream;

/**
 * This class prints out and counts warnings.
 *
 * @author Eric Lafortune
 */
public class WarningPrinter
{
    private PrintStream printStream;
    private int         warningCount;


    /**
     * Creates a new WarningPrinter that prints to the System.err print stream.
     */
    public WarningPrinter()
    {
        this(System.err);
    }


    /**
     * Creates a new WarningPrinter that prints to the given print stream.
     */
    public WarningPrinter(PrintStream printStream)
    {
        this.printStream = printStream;
    }


    /**
     * Prints out the given warning and increments the warning count.
     */
    public void print(String warning)
    {
        printStream.println(warning);

        warningCount++;
    }


    /**
     * Returns the number of warnings printed so far.
     */
    public int getWarningCount()
    {
        return warningCount;
    }
}

==> proguard_4.3.orig.tar.gz: proguard-4.3/src/proguard/classfile/util/WarningPrinter.java <==
/*
 * ProGuard -- shrinking, optimization, obfuscation, and preverification
 *             of Java bytecode.
 *
 * Copyright (c) 2002-2008 Eric Lafortune (eric@graphics.cornell.edu)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package proguard.classfile.util;

import java.io.PrintStream;

/**
 * This class prints out and counts warnings.
 *
 * @author Eric Lafortune
 */
public class WarningPrinter
{
    private final PrintStream printStream;
    private int         warningCount;


    /**
     * Creates a new WarningPrinter that prints to the System.err print stream.
     */
    public WarningPrinter()
    {
        this(System.err);
    }


    /**
     * Creates a new WarningPrinter that prints to the given print stream.
     */
    public WarningPrinter(PrintStream printStream)
    {
        this.printStream = printStream;
    }


    /**
     * Prints out the given warning and increments the warning count.
     */
    public void print(String warning)
    {
        printStream.println(warning);

        warningCount++;
    }


    /**
     * Returns the number of warnings printed so far.
     */
    public int getWarningCount()
    {
        return warningCount;
    }
}
